@@ -50,6 +50,9 @@
  */
 
 #define _XOPEN_SOURCE 500
+#define _DARWIN_C_SOURCE 1
+#define _BSD_SOURCE
+#define __BSD_VISIBLE 1
 #include <ctype.h>
 #include <stdio.h>
 #include <stdint.h>
@@ -350,7 +353,7 @@ int main(int argc, char ** argv) {
 	int ttype;
 	uint32_t option = 0, done = 0, sb_mode = 0;
 	/* Various pieces for the telnet communication */
-	char  sb[1024] = {0};
+	unsigned char  sb[1024] = {0};
 	unsigned short sb_len   = 0;
 
 	/* Whether or not to show the MOTD intro */
@@ -482,7 +485,7 @@ int main(int argc, char ** argv) {
 								/* This was a response to the TTYPE command, meaning
 								 * that this should be a terminal type */
 								alarm(2);
-								strcpy(term, &sb[2]);
+								strcpy(term, (char *)&sb[2]);
 								done++;
 							}
 							else if (sb[0] == NAWS) {
@@ -591,6 +594,8 @@ int main(int argc, char ** argv) {
 		ttype = 6; /* No color support */
 	} else if (strstr(term, "fallback")) {
 		ttype = 4; /* Unicode fallback */
+	} else if (strstr(term, "rxvt-256color")) {
+		ttype = 1; /* xterm 256-color compatible */
 	} else if (strstr(term, "rxvt")) {
 		ttype = 3; /* Accepts LINUX mode */
 	} else if (strstr(term, "vt100") && terminal_width == 40) {
